@@ -1,10 +1,10 @@
+from datetime import datetime
 from pydantic import BaseModel, Field
-from .User import User
-from .Beatmap import Beatmap
-from .Beatmapset import Beatmapset
+from .User import UserCompact
+from .Beatmap import BeatmapCompact
+from .Beatmapset import BeatmapsetCompact
 from .Extras import Weight, ScoreMatchInfo, Statistics
-from .enums import GameModeInt
-from typing import Optional
+from .Enums import GameModeInt
 
 # https://osu.ppy.sh/docs/index.html#score
 class Score(BaseModel):
@@ -18,23 +18,26 @@ class Score(BaseModel):
     passed: bool
     pp: float
     rank: str
-    created_at: str
+    created_at: datetime
     mode: str
     mode_int: GameModeInt
     replay: bool
     
     # optionals
-    beatmap: Beatmap
-    beatmapset: Beatmapset
-    rank_country: int
-    rank_global: int
-    weight: Weight
-    user: User
-    score_match: ScoreMatchInfo = Field(alias="match")
+    beatmap: BeatmapCompact | None
+    beatmapset: BeatmapsetCompact | None
+    rank_country: int | None
+    rank_global: int | None
+    weight: Weight | None
+    user: UserCompact | None
+    score_match: ScoreMatchInfo | None = Field(alias="match")
 
     class Config:
         allow_population_by_field_name = True
         arbitrary_types_allowed = True
+        json_encoders = {
+            datetime: str,
+		}
         
 # https://osu.ppy.sh/docs/index.html#beatmapuserscore
 class BeatmapUserScore(BaseModel):
@@ -44,10 +47,13 @@ class BeatmapUserScore(BaseModel):
 # https://osu.ppy.sh/docs/index.html#beatmapscores
 class BeatmapScores(BaseModel):
     scores: list[Score]
-    userScore: Optional[BeatmapUserScore] = None
+    userScore: BeatmapUserScore | None
 
     class Config:
         arbitrary_types_allowed = True
         
 class Scores(BaseModel):
-    __root__: list[Score]
\ No newline at end of file
+    scores: list[Score]
+    
+    class Config:
+        arbitrary_types_allowed = True
\ No newline at end of file
