@@ -1,8 +1,8 @@
-from .Beatmap import Beatmap, BeatmapCompact
+from .Beatmap import Beatmap, BeatmapCompact, Beatmaps
 from .Beatmapset import Beatmapset, BeatmapsetCompact
 from .Covers import Covers
 from .DifficultyAttributes import DifficultyAttributes
-from .enums import UserAcountHistoryTypes, UserListFilters, UserListSorts, UserListViews, GameMode, GameModeInt, ScoreTypes, RankingType, BeatmapsetDownload
+from .Enums import UserAcountHistoryTypes, UserListFilters, UserListSorts, UserListViews, GameMode, GameModeInt, ScoreTypes, RankingType, BeatmapsetDownload
 from .Extras import GradeCounts, Level, Cover, Country, RankHighest, RankHistory, ReplaysWatchedCount, ProfileBanner, Availability, Hype, Nominations, Weight, Page, Kudosu, Statistics, ScoreMatchInfo, Attributes, Giver, Post, Failtimes
 from .KudosuHistory import KudosuHistory
 from .Rankings import Spotlight, Spotlights, Cursor, Rankings
